@@ -16,34 +16,51 @@
 #
 ################################################################################
 
-dtriangle <- function(x, a=0, b=1, c=(a+b)/2) {
+dtriangle <- function(x, a=0, b=1, c=(a+b)/2) 
+{
   x1 <- length(x)
   a1 <- length(a)
   b1 <- length(b)
   c1 <- length(c)
 
-  dTest <- function(X){
-    if(any(is.na(X))){ # is.na is TRUE for NA, NaN, and FALSE
-      if(any(is.nan(X))) return(NaN) # to conform to qunif
+  dTest <- function(X)
+  {
+    xx <- 1
+    aa <- 2
+    bb <- 3
+    cc <- 4
+    if (any(is.na(X))) # is.na is TRUE for NA, NaN, and FALSE
+    { 
+      if (any(is.nan(X))) return(NaN) # to conform to qunif
       else return(NA) # to conform to qunif
-    } else if(X[2] > X[4] | X[3] < X[4] | (X[1]==X[2] & X[2]==X[4])){
+    } else if (X[aa] > X[cc] | X[bb] < X[cc] | (X[aa]==X[cc] & X[bb]==X[cc]))
+    {
       warning("values required to be  a <= c <= b (at least one strict inequality)")
       return(NaN) # to conform to behavior of qunif
-    } else if(any(is.infinite(X[2:4]))){
+    } else if (any(is.infinite(X[aa:cc]))){
       return(NaN)
-    } else if(X[1] <= X[2]) {
+    } else if (X[xx] < X[aa]) {
       return(0)
-    } else if(X[2] != X[4] & X[1] < X[4]){
-      return(2*(X[1] - X[2]) / (X[3] - X[2]) / (X[4] - X[2]))
-    } else if(X[4] != X[3] & X[1] >= X[4] & X[1] < X[3]){
-      return(2*(X[3] - X[1]) / (X[3] - X[2]) / (X[3] - X[4]))
-    } else if(X[1] >= X[3]){
+    } else if (X[xx] == X[aa] & X[aa] == X[cc])
+    {
+      return(2*(X[bb] - X[xx]) / (X[bb] - X[aa]) / (X[bb] - X[cc]))
+    } else if (X[aa] != X[cc] & X[xx] < X[cc])
+    {
+      return(2*(X[xx] - X[aa]) / (X[bb] - X[aa]) / (X[cc] - X[aa]))
+    } else if (X[cc] != X[bb] & X[xx] >= X[cc] & X[xx] <= X[bb])
+    {
+      return(2*(X[bb] - X[xx]) / (X[bb] - X[aa]) / (X[bb] - X[cc]))
+    } else if (X[xx] == X[bb] & X[bb] == X[cc])
+    {
+      return(2*(X[xx] - X[aa]) / (X[bb] - X[aa]) / (X[cc] - X[aa]))
+    } else if (X[xx] > X[bb])
+    {
       return(0)
-    }
+    } 
   }
 
   k <- max(x1, a1, b1, c1)
-  if(k==1) return(dTest(c(x, a, b, c)))
+  if (k==1) return(dTest(c(x, a, b, c)))
 
   params <- matrix(nrow=k, ncol=4)
   tryCatch(
